# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chopper.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'chopper.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rchopper.proto\x12\x07\x63hopper\"\x1b\n\x0b\x63hopMessage\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x0b\n\tchopReply2;\n\x07\x63hopper\x12\x30\n\x04\x43hop\x12\x14.chopper.chopMessage\x1a\x12.chopper.chopReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chopper_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHOPMESSAGE']._serialized_start=26
  _globals['_CHOPMESSAGE']._serialized_end=53
  _globals['_CHOPREPLY']._serialized_start=55
  _globals['_CHOPREPLY']._serialized_end=66
  _globals['_CHOPPER']._serialized_start=68
  _globals['_CHOPPER']._serialized_end=127
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages
setup(
    name='eztopo_utils',
    version='0.1.0',
    author='BryanTurns',
    author_email='turnsbryan@gmail.com',
    description='A short description of your package',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)